@@ -7,18 +7,23 @@
 
 #include "SourceFiles.h"
 
-using namespace std;
-using namespace Vera;
-using namespace Vera::Structures;
-
 
 namespace // unnamed
 {
 
-SourceFiles::FileNameSet files_;
+Vera::Structures::SourceFiles::FileNameSet files_;
 
 } // unnamed namespace
 
+namespace Vera
+{
+namespace Structures
+{
+
+int SourceFiles::count()
+{
+    return files_.size();
+}
 
 void SourceFiles::addFileName(const FileName & name)
 {
@@ -34,3 +39,6 @@ const SourceFiles::FileNameSet & SourceFiles::getAllFileNames()
 {
     return files_;
 }
+
+}
+}
